gchecky.model.default_tax_rule_t

Package gchecky :: Module model :: Class default_tax_rule_t |
[hide private]
[frames] | no frames]

# Class default_tax_rule_t

source code

    object --+
             |
     gxml.Node --+
                 |
        tax_rule_t --+
                     |
                    default_tax_rule_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| shipping_taxed = `gxml.Boolean('shipping-taxed', required= False)`
| _fields = ``{``'``rate``'``:` Double:PATH(rate):REQ`,` `'``shipping_taxed``'``:` `??``,` `...``
Inherited from `tax_rule_t`: `rate`, `tax_area`, `tax_areas`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields Value:
      {'rate': Double:PATH(rate):REQ,
       'shipping_taxed': ??,
       'tax_area': Node:PATH(tax-area):OPT:{ tax_area_t },
       'tax_areas': List:PATH(tax-areas):OPT:[
          Node:PATH():REQ:{ tax_area_t }
      ]}